@@ -1,4 +1,5 @@
-// -*- Mode: c++-mode; c-basic-offset: 2; indent-tabs-mode: t; tab-width: 2; -*-
+// vim: set noet ts=4 sts=4 sw=4 :
+// -*- Mode: c++; c-basic-offset: 2; indent-tabs-mode: t; tab-width: 2; -*-
 //
 // Copyright (C) 2003-2004 Grzegorz Jaskiewicz 	<gj at pointblue.com.pl>
 // Copyright (C) 2003 Zack Rusin 		<zack@kde.org>
@@ -17,13 +18,12 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-// 02111-1307, USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+// 02110-1301, USA
 
 #include "gaduaccount.h"
 #include "gaducontact.h"
 #include "gaduprotocol.h"
-#include "gaduawayui.h"
 #include "gaduaway.h"
 #include "gadupubdir.h"
 #include "gadudcc.h"
@@ -36,25 +36,32 @@
 #include "kopeteuiglobal.h"
 #include "kopeteglobal.h"
 
-#include <kpassdlg.h>
+#include <kpassworddialog.h>
 #include <kconfig.h>
 #include <kdebug.h>
+#include <kglobal.h>
 #include <klocale.h>
-#include <kpopupmenu.h>
+#include <kmenu.h>
 #include <kmessagebox.h>
-#include <knotifyclient.h>
-#include <ktempfile.h>
+#include <knotification.h>
+#include <ktemporaryfile.h>
+#include <kactionmenu.h>
+#include <ktoggleaction.h>
 #include <kio/netaccess.h>
+#include <kicon.h>
 
 #include <qapplication.h>
 #include <qdialog.h>
 #include <qtimer.h>
 #include <qtextcodec.h>
-#include <qptrlist.h>
 #include <qtextstream.h>
 #include <qhostaddress.h>
+//Added by qt3to4:
+#include <QByteArray>
+#include <QList>
 
 #include <netinet/in.h>
+#include <kconfiggroup.h>
 
 class GaduAccountPrivate {
 
@@ -65,12 +72,11 @@ public:
 	GaduDCC*	gaduDcc_;
 
 	QTimer*		pingTimer_;
-	
+
 	QTextCodec*	textcodec_;
 	KFileDialog*	saveListDialog;
 	KFileDialog*	loadListDialog;
 
-	KActionMenu*	actionMenu_;
 	KAction*	searchAction;
 	KAction*	listputAction;
 	KAction*	listToFileAction;
@@ -84,13 +90,13 @@ public:
 	QString		lastDescription;
 	bool		forFriends;
 	bool		ignoreAnons;
-        
+
 	QTimer*         exportTimer_;
 	bool		exportUserlist;
-	
+
 	KConfigGroup*			config;
 	Kopete::OnlineStatus		status;
-	QValueList<unsigned int>	servers;
+	QList<unsigned int>		servers;
 	KGaduLoginParams		loginInfo;
 };
 
@@ -99,23 +105,27 @@ public:
 
 // FIXME: use dynamic cache please, i consider this as broken resolution of this problem
 static const char* const servers_ip[] = {
+	"217.17.41.88",
 	"217.17.41.85",
+	"217.17.45.143",
+	"217.17.45.144",
+	"217.17.45.145",
+	"217.17.45.146",
+	"217.17.45.147",
+	"217.17.41.82",
 	"217.17.41.83",
 	"217.17.41.84",
 	"217.17.41.86",
 	"217.17.41.87",
-	"217.17.41.88",
 	"217.17.41.92",
 	"217.17.41.93",
-	"217.17.45.133",
-	"217.17.45.143",
-	"217.17.45.144"
+	"217.17.45.133"
 };
 
 #define NUM_SERVERS (sizeof(servers_ip)/sizeof(char*))
 
- GaduAccount::GaduAccount( Kopete::Protocol* parent, const QString& accountID,const char* name )
-: Kopete::PasswordedAccount( parent, accountID, 0, name )
+ GaduAccount::GaduAccount( Kopete::Protocol* parent, const QString& accountID )
+: Kopete::PasswordedAccount( parent, accountID, false )
 {
 	QHostAddress ip;
 	p = new GaduAccountPrivate;
@@ -126,19 +136,18 @@ static const char* const servers_ip[] = {
 	p->forFriends = false;
 
 	p->textcodec_ = QTextCodec::codecForName( "CP1250" );
-	p->session_ = new GaduSession( this, "GaduSession" );
-
-	KGlobal::config()->setGroup( "Gadu" );
+	p->session_ = new GaduSession( this );
+	p->session_->setObjectName( QLatin1String("GaduSession") );
 
 	setMyself( new GaduContact( accountId().toInt(), accountId(), this, Kopete::ContactList::self()->myself() ) );
 
 	p->status = GaduProtocol::protocol()->convertStatus( GG_STATUS_NOT_AVAIL );
-	p->lastDescription = QString::null;
+	p->lastDescription.clear();
 
 	for ( unsigned int i = 0; i < NUM_SERVERS ; i++ ) {
 		ip.setAddress( QString( servers_ip[i] ) );
 		p->servers.append( htonl( ip.toIPv4Address() ) );
-		kdDebug( 14100 ) << "adding IP: " <<  p->servers[ i ] << " to cache" << endl;
+		kDebug( 14100 ) << "adding IP: " <<  p->servers[ i ] << " to cache";
 	}
 	p->currentServer = -1;
 	p->serverIP = 0;
@@ -165,7 +174,7 @@ static const char* const servers_ip[] = {
 	initConnections();
 	initActions();
 
-	QString nick = p->config->readEntry( QString::fromAscii( "nickName" ) );
+	QString nick = p->config->readEntry( QString::fromAscii( "nickName" ), QString() );
 	if ( !nick.isNull() ) {
 		myself()->setProperty( Kopete::Global::Properties::self()->nickName(), nick );
 	}
@@ -183,17 +192,21 @@ GaduAccount::~GaduAccount()
 void
 GaduAccount::initActions()
 {
-	p->searchAction		= new KAction( i18n( "&Search for Friends" ), "", 0,
-							this, SLOT( slotSearch() ), this, "actionSearch" );
-	p->listputAction		= new KAction( i18n( "Export Contacts to Server" ), "", 0,
-							this, SLOT( slotExportContactsList() ), this, "actionListput" );
-	p->listToFileAction	= new KAction( i18n( "Export Contacts to File..." ), "", 0,
-							this, SLOT( slotExportContactsListToFile() ), this, "actionListputFile" );
-	p->listFromFileAction	= new KAction( i18n( "Import Contacts From File..." ), "", 0,
-							this, SLOT( slotImportContactsFromFile() ), this, "actionListgetFile" );
-	p->friendsModeAction	= new KToggleAction( i18n( "Only for Friends" ), "", 0,
-							this, SLOT( slotFriendsMode() ), this,
-							"actionFriendsMode" );
+	p->searchAction		= new KAction( i18n( "&Search for Friends" ), this );
+        //, "actionSearch" );
+	QObject::connect( p->searchAction, SIGNAL(triggered(bool)), this, SLOT(search()) );
+	p->listputAction		= new KAction( i18n( "Export Contacts to Server" ), this );
+        //, "actionListput" );
+	QObject::connect( p->listputAction, SIGNAL(triggered(bool)), this, SLOT(slotExportContactsList()) );
+	p->listToFileAction	= new KAction( i18n( "Export Contacts to File..." ), this );
+        //, "actionListputFile" );
+	QObject::connect( p->listToFileAction, SIGNAL(triggered(bool)), this, SLOT(slotExportContactsListToFile()) );
+	p->listFromFileAction	= new KAction( i18n( "Import Contacts From File..." ), this );
+        //, "actionListgetFile" );
+	QObject::connect( p->listFromFileAction, SIGNAL(triggered(bool)), this, SLOT(slotImportContactsFromFile()) );
+	p->friendsModeAction	= new KToggleAction( i18n( "Only for Friends" ), this );
+        //, "actionFriendsMode" );
+	QObject::connect( p->friendsModeAction, SIGNAL(triggered(bool)), this, SLOT(slotFriendsMode()) );
 
 	static_cast<KToggleAction*>(p->friendsModeAction)->setChecked( p->forFriends );
 }
@@ -246,81 +259,100 @@ GaduAccount::setAway( bool isAway, const QString& awayMessage )
 }
 
 
-KActionMenu*
-GaduAccount::actionMenu()
+void
+GaduAccount::fillActionMenu( KActionMenu *actionMenu )
 {
-	kdDebug(14100) << "actionMenu() " << endl;
+	kDebug(14100);
 
-	p->actionMenu_ = new KActionMenu( accountId(), myself()->onlineStatus().iconFor( this ), this );
-	p->actionMenu_->popupMenu()->insertTitle( myself()->onlineStatus().iconFor( myself() ), i18n( "%1 <%2> " ).
-	    arg( myself()->property( Kopete::Global::Properties::self()->nickName()).value().toString(), accountId() ) );
+	actionMenu->setIcon( myself()->onlineStatus().iconFor( this ) );
+	actionMenu->menu()->addTitle( myself()->onlineStatus().iconFor( myself() ), i18n( "%1 <%2> ",
+	    myself()->property( Kopete::Global::Properties::self()->nickName()).value().toString(), accountId() ) );
 
 	if ( p->session_->isConnected() ) {
-		p->searchAction->setEnabled( TRUE );
-		p->listputAction->setEnabled( TRUE );
-		p->friendsModeAction->setEnabled( TRUE );
+		p->searchAction->setEnabled( true );
+		p->listputAction->setEnabled( true );
+		p->friendsModeAction->setEnabled( true );
 	}
 	else {
-		p->searchAction->setEnabled( FALSE );
-		p->listputAction->setEnabled( FALSE );
-		p->friendsModeAction->setEnabled( FALSE );
+		p->searchAction->setEnabled( false );
+		p->listputAction->setEnabled( false );
+		p->friendsModeAction->setEnabled( false );
 	}
 
 	if ( contacts().count() > 1 ) {
 		if ( p->saveListDialog ) {
-			p->listToFileAction->setEnabled( FALSE );
+			p->listToFileAction->setEnabled( false );
 		}
 		else {
-			p->listToFileAction->setEnabled( TRUE );
+			p->listToFileAction->setEnabled( true );
 		}
 
-		p->listToFileAction->setEnabled( TRUE );
+		p->listToFileAction->setEnabled( true );
 	}
 	else {
-		p->listToFileAction->setEnabled( FALSE );
+		p->listToFileAction->setEnabled( false );
 	}
 
 	if ( p->loadListDialog ) {
-		p->listFromFileAction->setEnabled( FALSE );
+		p->listFromFileAction->setEnabled( false );
 	}
 	else {
-		p->listFromFileAction->setEnabled( TRUE );
+		p->listFromFileAction->setEnabled( true );
 	}
-	p->actionMenu_->insert( new KAction( i18n( "Go O&nline" ),
-				GaduProtocol::protocol()->convertStatus( GG_STATUS_AVAIL ).iconFor( this ),
-				0, this, SLOT( slotGoOnline() ), this, "actionGaduConnect" ) );
 
-	p->actionMenu_->insert( new KAction( i18n( "Set &Busy" ),
-				GaduProtocol::protocol()->convertStatus( GG_STATUS_BUSY ).iconFor( this ),
-				0, this, SLOT( slotGoBusy() ), this, "actionGaduConnect" ) );
+	KAction* action = new KAction(
+		KIcon(QIcon(GaduProtocol::protocol()->convertStatus( GG_STATUS_AVAIL ).iconFor( this ))),
+		i18n("Go O&nline"), this );
+        //, "actionGaduConnect" );
+	QObject::connect( action, SIGNAL(triggered(bool)), this, SLOT(slotGoOnline()));
+	actionMenu->addAction( action );
 
-	p->actionMenu_->insert( new KAction( i18n( "Set &Invisible" ),
-				GaduProtocol::protocol()->convertStatus( GG_STATUS_INVISIBLE ).iconFor( this ),
-				0, this, SLOT( slotGoInvisible() ), this, "actionGaduConnect" ) );
+	action = new KAction(
+		KIcon(QIcon(GaduProtocol::protocol()->convertStatus( GG_STATUS_BUSY ).iconFor( this ))),
+		i18n( "Set &Busy" ), this );
+        //, "actionGaduConnect" );
+	QObject::connect( action, SIGNAL(triggered(bool)), this, SLOT(slotGoBusy()) );
+	actionMenu->addAction( action );
 
-	p->actionMenu_->insert( new KAction( i18n( "Go &Offline" ),
-				GaduProtocol::protocol()->convertStatus( GG_STATUS_NOT_AVAIL ).iconFor( this ),
-				0, this, SLOT( slotGoOffline() ), this, "actionGaduConnect" ) );
+	action = new KAction(
+		KIcon(QIcon(GaduProtocol::protocol()->convertStatus( GG_STATUS_INVISIBLE ).iconFor( this ))),
+		i18n( "Set &Invisible" ), this );
+        //, "actionGaduConnect" );
+	QObject::connect( action, SIGNAL(triggered(bool)), this, SLOT(slotGoInvisible()) );
+	actionMenu->addAction( action );
 
-	p->actionMenu_->insert( new KAction( i18n( "Set &Description..." ), "info",
-			0, this, SLOT( slotDescription() ), this, "actionGaduDescription" ) );
+	action = new KAction(
+		KIcon(QIcon(GaduProtocol::protocol()->convertStatus( GG_STATUS_NOT_AVAIL ).iconFor( this ))),
+		i18n( "Go &Offline" ), this );
+        //, "actionGaduConnect" );
+	QObject::connect( action, SIGNAL(triggered(bool)), this, SLOT(slotGoOffline()) );
+	actionMenu->addAction( action );
 
-	p->actionMenu_->insert( p->friendsModeAction );
+	action = new KAction( KIcon("edit-rename"), i18n( "Set &Description..." ), this );
+        //, "actionGaduDescription" );
+	QObject::connect( action, SIGNAL(triggered(bool)), this, SLOT(slotDescription()) );
+	actionMenu->addAction( action );
 
-	p->actionMenu_->popupMenu()->insertSeparator();
+	actionMenu->addAction( p->friendsModeAction );
 
-	p->actionMenu_->insert( p->searchAction );
+	actionMenu->addSeparator();
 
-	p->actionMenu_->popupMenu()->insertSeparator();
+	actionMenu->addAction( p->searchAction );
 
-	p->actionMenu_->insert( p->listputAction );
+	actionMenu->addSeparator();
 
-	p->actionMenu_->popupMenu()->insertSeparator();
+	actionMenu->addAction( p->listputAction );
 
-	p->actionMenu_->insert( p->listToFileAction );
-	p->actionMenu_->insert( p->listFromFileAction );
+	actionMenu->addSeparator();
 
-	return p->actionMenu_;
+	actionMenu->addAction( p->listToFileAction );
+	actionMenu->addAction( p->listFromFileAction );
+}
+
+bool
+GaduAccount::hasCustomStatusMenu() const
+{
+	return true;
 }
 
 void
@@ -350,10 +382,16 @@ GaduAccount::disconnect( DisconnectReason reason )
 }
 
 void
-GaduAccount::setOnlineStatus( const Kopete::OnlineStatus& status , const QString &reason )
+GaduAccount::setOnlineStatus( const Kopete::OnlineStatus& status , const Kopete::StatusMessage &reason, const OnlineStatusOptions& options )
 {
-	kdDebug(14100) << k_funcinfo << "Called" << endl;
-	changeStatus( status, reason);
+	kDebug(14100) << "Called";
+	changeStatus( status, reason.message() );
+}
+
+void
+GaduAccount::setStatusMessage( const Kopete::StatusMessage& statusMessage )
+{
+	changeStatus( myself()->onlineStatus(), statusMessage.message() );
 }
 
 void
@@ -363,7 +401,7 @@ GaduAccount::slotUserlistSynch()
 		return;
 	}
 	p->exportUserlist = false;
-	kdDebug(14100) << "userlist changed, exporting" << endl;
+	kDebug(14100) << "userlist changed, exporting";
 	slotExportContactsList();
 }
 
@@ -371,13 +409,13 @@ void
 GaduAccount::userlistChanged()
 {
 	p->exportUserlist = true;
-	p->exportTimer_->changeInterval( USERLISTEXPORT_TIMEOUT );
+	p->exportTimer_->start( USERLISTEXPORT_TIMEOUT );
 }
 
 bool
 GaduAccount::createContact( const QString& contactId, Kopete::MetaContact* parentContact )
 {
-	kdDebug(14100) << "createContact " << contactId << endl;
+	kDebug(14100) << "createContact " << contactId;
 
 	uin_t uinNumber = contactId.toUInt();
 	GaduContact* newContact = new GaduContact( uinNumber, parentContact->displayName(),this, parentContact );
@@ -385,7 +423,7 @@ GaduAccount::createContact( const QString& contactId, Kopete::MetaContact* paren
 	addNotify( uinNumber );
 
 	userlistChanged();
-	
+
 	return true;
 }
 
@@ -393,10 +431,10 @@ void
 GaduAccount::changeStatus( const Kopete::OnlineStatus& status, const QString& descr )
 {
 	unsigned int ns;
-	
-	kdDebug(14100) << "##### change status #####" << endl;
-	kdDebug(14100) << "### Status = " << p->session_->isConnected() << endl;
-	kdDebug(14100) << "### Status description = \"" << descr << "\"" << endl;
+
+	kDebug(14100) << "##### change status #####";
+	kDebug(14100) << "### Status = " << p->session_->isConnected();
+	kDebug(14100) << "### Status description = \"" << descr << "\"";
 
 	// if change to not available, log off
 	if ( GG_S_NA( status.internalStatus() ) ) {
@@ -428,7 +466,7 @@ GaduAccount::changeStatus( const Kopete::OnlineStatus& status, const QString& de
 			changeStatus( GaduProtocol::protocol()->convertStatus( ns ), descr );
 			return;
 		}
-				
+
 		if ( !p->session_->isConnected() ) {
 			if ( password().cachedValue().isEmpty() ) {
 				// FIXME: when status string added to connect(), use it here
@@ -447,7 +485,7 @@ GaduAccount::changeStatus( const Kopete::OnlineStatus& status, const QString& de
 			p->serverIP = 0;
 			p->currentServer = -1;
 			p->status = status;
-			kdDebug(14100) << "#### Connecting..., tls option "<< (int)useTls() << " " << endl;
+			kDebug(14100) << "#### Connecting..., tls option "<< (int)useTls() << " ";
 			p->lastDescription = descr;
 			slotLogin( status.internalStatus(), descr );
 			return;
@@ -466,7 +504,7 @@ GaduAccount::changeStatus( const Kopete::OnlineStatus& status, const QString& de
 	}
 
 	myself()->setOnlineStatus( status );
-	myself()->setProperty( GaduProtocol::protocol()->propAwayMessage, descr );
+	myself()->setStatusMessage( Kopete::StatusMessage(descr) );
 
 	if ( status.internalStatus() == GG_STATUS_NOT_AVAIL || status.internalStatus() == GG_STATUS_NOT_AVAIL_DESCR ) {
 		if ( p->pingTimer_ ){
@@ -482,14 +520,14 @@ GaduAccount::slotLogin( int status, const QString& dscr )
 	p->lastDescription	= dscr;
 
 	myself()->setOnlineStatus( GaduProtocol::protocol()->convertStatus( GG_STATUS_CONNECTING ));
-	myself()->setProperty( GaduProtocol::protocol()->propAwayMessage, dscr );
+	myself()->setStatusMessage( Kopete::StatusMessage(dscr) );
 
 	if ( !p->session_->isConnected() ) {
 		if ( password().cachedValue().isEmpty() ) {
 			connectionFailed( GG_FAILURE_PASSWORD );
 		}
 		else {
-			p->loginInfo.password		= password().cachedValue();
+			p->loginInfo.password		= p->textcodec_->fromUnicode(password().cachedValue());
 			p->loginInfo.useTls		= p->connectWithSSL;
 			p->loginInfo.status		= status;
 			p->loginInfo.statusDescr	= dscr;
@@ -590,13 +628,13 @@ void
 GaduAccount::messageReceived( KGaduMessage* gaduMessage )
 {
 	GaduContact* contact = 0;
-	QPtrList<Kopete::Contact> contactsListTmp;
+	QList<Kopete::Contact*> contactsListTmp;
 
 	// FIXME:check for ignored users list
 
 	if ( gaduMessage->sender_id == 0 ) {
 		//system message, display them or not?
-		kdDebug(14100) << "####" << " System Message " << gaduMessage->message << endl;
+		kDebug(14100) << "####" << " System Message " << gaduMessage->message;
 		return;
 	}
 
@@ -616,7 +654,12 @@ GaduAccount::messageReceived( KGaduMessage* gaduMessage )
 	}
 
 	contactsListTmp.append( myself() );
-	Kopete::Message msg( gaduMessage->sendTime, contact, contactsListTmp, gaduMessage->message, Kopete::Message::Inbound, Kopete::Message::RichText );
+
+	Kopete::Message msg( contact, contactsListTmp );
+	msg.setTimestamp( gaduMessage->sendTime );
+	msg.setHtmlBody( gaduMessage->message );
+	msg.setDirection( Kopete::Message::Inbound );
+
 	contact->messageReceived( msg );
 }
 
@@ -627,24 +670,24 @@ GaduAccount::ackReceived( unsigned int recipient  )
 
 	contact = static_cast<GaduContact*> ( contacts()[ QString::number( recipient ) ] );
 	if ( contact ) {
-		kdDebug(14100) << "####" << "Received an ACK from " << contact->uin() << endl;
+		kDebug(14100) << "####" << "Received an ACK from " << contact->uin();
 		contact->messageAck();
 	}
 	else {
-		kdDebug(14100) << "####" << "Received an ACK from an unknown user : " << recipient << endl;
+		kDebug(14100) << "####" << "Received an ACK from an unknown user : " << recipient;
 	}
 }
 
 void
 GaduAccount::contactStatusChanged( KGaduNotify* gaduNotify )
 {
-	kdDebug(14100) << "####" << " contact's status changed, uin:" << gaduNotify->contact_id <<endl;
+	kDebug(14100) << "####" << " contact's status changed, uin:" << gaduNotify->contact_id;
 
 	GaduContact* contact;
 
 	contact = static_cast<GaduContact*>( contacts()[ QString::number( gaduNotify->contact_id ) ] );
 	if( !contact ) {
-		kdDebug(14100) << "Notify not in the list " << gaduNotify->contact_id << endl;
+		kDebug(14100) << "Notify not in the list " << gaduNotify->contact_id;
 		return;
 	}
 
@@ -654,13 +697,13 @@ GaduAccount::contactStatusChanged( KGaduNotify* gaduNotify )
 void
 GaduAccount::pong()
 {
-	kdDebug(14100) << "####" << " Pong..." << endl;
+	kDebug(14100) << "####" << " Pong...";
 }
 
 void
 GaduAccount::pingServer()
 {
-	kdDebug(14100) << "####" << " Ping..." << endl;
+	kDebug(14100) << "####" << " Ping...";
 	p->session_->ping();
 }
 
@@ -682,8 +725,8 @@ GaduAccount::connectionFailed( gg_failure_t failure )
 		default:
 			if ( p->connectWithSSL ) {
 				if ( useTls() != TLS_only ) {
-					slotCommandDone( QString::null, i18n( "connection using SSL was not possible, retrying without." ) );
-					kdDebug( 14100 ) << "try without tls now" << endl;
+					slotCommandDone( QString(), i18n( "connection using SSL was not possible, retrying without." ) );
+					kDebug( 14100 ) << "try without tls now";
 					p->connectWithSSL = false;
 					tryReconnect = true;
 					p->currentServer = -1;
@@ -695,11 +738,11 @@ GaduAccount::connectionFailed( gg_failure_t failure )
 				if ( p->currentServer == NUM_SERVERS - 1 ) {
 					p->serverIP = 0;
 					p->currentServer = -1;
-					kdDebug(14100) << "trying : " << "IP from hub " << endl;
+					kDebug(14100) << "trying : " << "IP from hub ";
 				}
 				else {
 					p->serverIP = p->servers[ ++p->currentServer ];
-					kdDebug(14100) << "trying : " << p->currentServer << " IP " << p->serverIP << endl;
+					kDebug(14100) << "trying : " << p->currentServer << " IP " << p->serverIP;
 					tryReconnect = true;
 				}
 			}
@@ -710,7 +753,7 @@ GaduAccount::connectionFailed( gg_failure_t failure )
 			slotLogin( p->status.internalStatus() , p->lastDescription );
 	}
 	else {
-		error( i18n( "unable to connect to the Gadu-Gadu server(\"%1\")." ).arg( GaduSession::failureDescription( failure ) ),
+		error( i18n( "unable to connect to the Gadu-Gadu server(\"%1\").", GaduSession::failureDescription( failure ) ),
 				i18n( "Connection Error" ) );
 		p->status = GaduProtocol::protocol()->convertStatus( GG_STATUS_NOT_AVAIL );
 		myself()->setOnlineStatus( p->status );
@@ -725,7 +768,7 @@ GaduAccount::dccOn()
 		if ( !p->gaduDcc_ ) {
 			p->gaduDcc_ = new GaduDCC( this );
 		}
-		kdDebug( 14100 ) << " turn DCC on for " << accountId() << endl;
+		kDebug( 14100 ) << " turn DCC on for " << accountId();
 		p->gaduDcc_->registerAccount( this );
 		p->loginInfo.client_port	= p->gaduDcc_->listeingPort();
 	}
@@ -735,7 +778,7 @@ void
 GaduAccount::dccOff()
 {
 	if ( p->gaduDcc_ ) {
-		kdDebug( 14100 ) << "destroying dcc in gaduaccount " << endl;
+		kDebug( 14100 ) << "destroying dcc in gaduaccount ";
 		delete p->gaduDcc_;
 		p->gaduDcc_ = NULL;
 		p->loginInfo.client_port	= 0;
@@ -756,13 +799,13 @@ GaduAccount::slotIncomingDcc( unsigned int uin )
 	contact = static_cast<GaduContact*>( contacts()[ QString::number( uin ) ] );
 
 	if ( !contact ) {
-	  kdDebug(14100) << "attempt to make dcc connection from unknown uin " << uin << endl;
+	  kDebug(14100) << "attempt to make dcc connection from unknown uin " << uin;
 		return;
 	}
 
 	// if incapabile to transfer files, forget about it.
 	if ( contact->contactPort() < 10 ) {
-	  kdDebug(14100) << "can't respond to " << uin << " request, his listeing port is too low" << endl;
+	  kDebug(14100) << "can't respond to " << uin << " request, his listeing port is too low";
 	  return;
 	}
 
@@ -776,10 +819,10 @@ GaduAccount::slotIncomingDcc( unsigned int uin )
 void
 GaduAccount::connectionSucceed( )
 {
-	kdDebug(14100) << "#### Gadu-Gadu connected! " << endl;
+	kDebug(14100) << "#### Gadu-Gadu connected! ";
 	p->status =  GaduProtocol::protocol()->convertStatus( p->session_->status() );
 	myself()->setOnlineStatus( p->status );
-	myself()->setProperty( GaduProtocol::protocol()->propAwayMessage, p->lastDescription );
+	myself()->setStatusMessage( Kopete::StatusMessage(p->lastDescription) );
 	startNotify();
 
 	p->session_->requestContacts();
@@ -798,13 +841,13 @@ GaduAccount::startNotify()
 		return;
 	}
 
-	QDictIterator<Kopete::Contact> kopeteContactsList( contacts() );
-
 	uin_t* userlist = 0;
 	userlist = new uin_t[ contacts().count() ];
 
-	for( i=0 ; kopeteContactsList.current() ; ++kopeteContactsList ) {
-		userlist[i++] = static_cast<GaduContact*> ((*kopeteContactsList))->uin();
+	QHashIterator<QString, Kopete::Contact*> it(contacts());
+	for(  i=0 ; it.hasNext() ; ) {
+		it.next();
+		userlist[i++] = static_cast<GaduContact*> (it.value())->uin();
 	}
 
 	p->session_->notify( userlist, contacts().count() );
@@ -816,7 +859,7 @@ GaduAccount::slotSessionDisconnect( Kopete::Account::DisconnectReason reason )
 {
 	uin_t status;
 
-	kdDebug(14100) << "Disconnecting" << endl;
+	kDebug(14100) << "Disconnecting";
 
 	if (p->pingTimer_) {
 		p->pingTimer_->stop();
@@ -834,7 +877,7 @@ GaduAccount::slotSessionDisconnect( Kopete::Account::DisconnectReason reason )
 void
 GaduAccount::userlist( const QString& contactsListString )
 {
-	kdDebug(14100)<<"### Got userlist - gadu account"<<endl;
+	kDebug(14100)<<"### Got userlist - gadu account";
 
 	GaduContactsList contactsList( contactsListString );
 	QString contactName;
@@ -845,29 +888,29 @@ GaduAccount::userlist( const QString& contactsListString )
 
 	// don't export any new changes that were just imported :-)
 	p->exportTimer_->stop();
-	
+
 	for ( i = 0; i != contactsList.size() ; i++ ) {
-		kdDebug(14100) << "uin " << contactsList[i].uin << endl;
+		kDebug(14100) << "uin " << contactsList[i].uin;
 
 		if ( contactsList[i].uin.isNull() ) {
-			kdDebug(14100) << "no Uin, strange.. "<<endl;
+			kDebug(14100) << "no Uin, strange.. ";
 			continue;
 		}
 
 		if ( contacts()[ contactsList[i].uin ] ) {
-			kdDebug(14100) << "UIN already exists in contacts "<< contactsList[i].uin << endl;
+			kDebug(14100) << "UIN already exists in contacts "<< contactsList[i].uin;
 		}
 		else {
 			contactName = GaduContact::findBestContactName( &contactsList[i] );
 			bool s = addContact( contactsList[i].uin, contactName, 0L, Kopete::Account::DontChangeKABC);
 			if ( s == false ) {
-				kdDebug(14100) << "There was a problem adding UIN "<< contactsList[i].uin << "to users list" << endl;
+				kDebug(14100) << "There was a problem adding UIN "<< contactsList[i].uin << "to users list";
 				continue;
 			}
 		}
 		contact = static_cast<GaduContact*>( contacts()[ contactsList[i].uin ] );
 		if ( contact == NULL ) {
-			kdDebug(14100) << "oops, no Kopete::Contact in contacts()[] for some reason, for \"" << contactsList[i].uin << "\"" << endl;
+			kDebug(14100) << "oops, no Kopete::Contact in contacts()[] for some reason, for \"" << contactsList[i].uin << "\"";
 			continue;
 		}
 
@@ -880,28 +923,28 @@ GaduAccount::userlist( const QString& contactsListString )
 			metaContact = contact->metaContact();
 			metaContact->removeFromGroup( Kopete::Group::topLevel() );
 			// put him in all desired groups:
-			groups = QStringList::split( ",", contactsList[i].group );
+			groups = contactsList[i].group.split( ",", QString::SkipEmptyParts );
 			for ( QStringList::Iterator groupsIterator = groups.begin(); groupsIterator != groups.end(); ++groupsIterator ) {
 				metaContact->addToGroup( Kopete::ContactList::self ()->findGroup ( *groupsIterator) );
 			}
 		}
 	}
-	// start to check if we need to export userlist 
-	p->exportUserlist = false;	
+	// start to check if we need to export userlist
+	p->exportUserlist = false;
 	p->exportTimer_->start( USERLISTEXPORT_TIMEOUT );
 }
 
 void
 GaduAccount::userListExportDone()
 {
-	slotCommandDone( QString::null, i18n( "Contacts exported to the server.") );
+	slotCommandDone( QString(), i18n( "Contacts exported to the server.") );
 }
 
 void
 GaduAccount::slotFriendsMode()
 {
 	p->forFriends = !p->forFriends;
-	kdDebug( 14100 ) << "for friends mode: " << p->forFriends << " desc" << p->lastDescription << endl;
+	kDebug( 14100 ) << "for friends mode: " << p->forFriends << " desc" << p->lastDescription;
 	// now change status, it will changing it with p->forFriends flag
 	changeStatus( p->status, p->lastDescription );
 
@@ -914,35 +957,34 @@ GaduAccount::slotFriendsMode()
 void
 GaduAccount::slotExportContactsListToFile()
 {
-	KTempFile tempFile;
-	tempFile.setAutoDelete( true );
+	KTemporaryFile tempFile;
 
 	if ( p->saveListDialog ) {
-		kdDebug( 14100 ) << " save contacts to file: alread waiting for input " << endl ;
+		kDebug( 14100 ) << " save contacts to file: alread waiting for input ";
 		return;
 	}
 
-	p->saveListDialog = new KFileDialog( "::kopete-gadu" + accountId(), QString::null,
-					Kopete::UI::Global::mainWidget(), "gadu-list-save", false );
+	p->saveListDialog = new KFileDialog( "::kopete-gadu" + accountId(), QString(),
+					Kopete::UI::Global::mainWidget() );
 	p->saveListDialog->setCaption(
-	    i18n("Save Contacts List for Account %1 As").arg(
+	    i18n("Save Contacts List for Account %1 As",
 	    myself()->property( Kopete::Global::Properties::self()->nickName()).value().toString() ) );
 
 	if ( p->saveListDialog->exec() == QDialog::Accepted ) {
-		QCString list = p->textcodec_->fromUnicode( userlist()->asString() );
+		QByteArray list = p->textcodec_->fromUnicode( userlist()->asString() );
 
-		if ( tempFile.status() ) {
+		if ( !tempFile.open() ) {
 			// say cheese, can't create file.....
 			error( i18n( "Unable to create temporary file." ), i18n( "Save Contacts List Failed" ) );
 		}
 		else {
-			QTextStream* tempStream = tempFile.textStream();
-			(*tempStream) << list.data();
-			tempFile.close();
+			QTextStream tempStream ( &tempFile );
+			tempStream << list.data();
+			tempStream.flush();
 
 			bool res = KIO::NetAccess::upload(
-								tempFile.name() ,
-								p->saveListDialog->selectedURL() ,
+								tempFile.fileName() ,
+								p->saveListDialog->selectedUrl() ,
 								Kopete::UI::Global::mainWidget()
 								);
 			if ( !res ) {
@@ -959,34 +1001,34 @@ GaduAccount::slotExportContactsListToFile()
 void
 GaduAccount::slotImportContactsFromFile()
 {
-	KURL url;
-	QCString list;
+	KUrl url;
+	QByteArray list;
 	QString oname;
 
 	if ( p->loadListDialog ) {
-		kdDebug( 14100 ) << "load contacts from file: alread waiting for input " << endl ;
+		kDebug( 14100 ) << "load contacts from file: alread waiting for input ";
 		return;
 	}
 
-	p->loadListDialog = new KFileDialog( "::kopete-gadu" + accountId(), QString::null,
-					Kopete::UI::Global::mainWidget(), "gadu-list-load", true );
+	p->loadListDialog = new KFileDialog( "::kopete-gadu" + accountId(), QString(),
+					Kopete::UI::Global::mainWidget() );
 	p->loadListDialog->setCaption(
-	    i18n("Load Contacts List for Account %1 As").arg(
+	    i18n("Load Contacts List for Account %1 As",
 	    myself()->property( Kopete::Global::Properties::self()->nickName()).value().toString() ) );
 
 	if ( p->loadListDialog->exec() == QDialog::Accepted ) {
-		url = p->loadListDialog->selectedURL();
-		kdDebug(14100) << "a:" << url << "\nb:" << oname << endl;
+		url = p->loadListDialog->selectedUrl();
+		kDebug(14100) << "a:" << url << "\nb:" << oname;
 		if ( KIO::NetAccess::download( url, oname, Kopete::UI::Global::mainWidget() ) ) {
 			QFile tempFile( oname );
-			if ( tempFile.open( IO_ReadOnly ) ) {
+			if ( tempFile.open( QIODevice::ReadOnly ) ) {
 				list = tempFile.readAll();
 				tempFile.close();
 				KIO::NetAccess::removeTempFile( oname );
 				// and store it
-				kdDebug( 14100 ) << "loaded list:" << endl;
-				kdDebug( 14100 ) << list << endl;
-				kdDebug( 14100 ) << " --------------- " << endl;
+				kDebug( 14100 ) << "loaded list:";
+				kDebug( 14100 ) << list;
+				kDebug( 14100 ) << " --------------- ";
 				userlist( p->textcodec_->toUnicode( list ) );
 			}
 			else {
@@ -1011,7 +1053,7 @@ GaduAccount::getPersonalInformation()
 	return p->session_->getPersonalInformation();
 }
 
-bool 
+bool
 GaduAccount::publishPersonalInformation( ResLine& d )
 {
 	return p->session_->publishPersonalInformation( d );
@@ -1028,16 +1070,16 @@ GaduAccount::userlist()
 {
 	GaduContact* contact;
 	GaduContactsList* contactsList = new GaduContactsList();
-	int i;
 
 	if ( !contacts().count() ) {
 		return contactsList;
 	}
 
-	QDictIterator<Kopete::Contact> contactsIterator( contacts() );
+	QHashIterator<QString, Kopete::Contact*> contactsIterator( contacts() );
 
-	for( i=0 ; contactsIterator.current() ; ++contactsIterator ) {
-		contact = static_cast<GaduContact*>( *contactsIterator );
+	for( ; contactsIterator.hasNext() ; ) {
+		contactsIterator.next();
+		contact = static_cast<GaduContact*>( contactsIterator.value() );
 		if ( contact->uin() != static_cast<GaduContact*>( myself() )->uin() ) {
 			contactsList->addContact( *contact->contactDetails() );
 		}
@@ -1049,7 +1091,8 @@ GaduAccount::userlist()
 void
 GaduAccount::slotSearch( int uin )
 {
-	new GaduPublicDir( this, uin );
+	GaduPublicDir* dir = new GaduPublicDir( this, uin );
+	dir->setObjectName( QLatin1String("GaduPublicDir") );
 }
 
 void
@@ -1061,8 +1104,7 @@ void
 GaduAccount::slotCommandDone( const QString& /*title*/, const QString& what )
 {
 	//FIXME: any chance to have my own title in event popup ?
-	KNotifyClient::userEvent( 0, what,
-			KNotifyClient::PassivePopup, KNotifyClient::Notification  );
+	KNotification::event( KNotification::Notification, what );
 }
 
 void
@@ -1120,8 +1162,8 @@ GaduAccount::dccRequest( GaduContact* peer )
 bool
 GaduAccount::dccEnabled()
 {
-	QString s = p->config->readEntry( QString::fromAscii( "useDcc" ) );
-	kdDebug( 14100 ) << "dccEnabled: "<< s << endl;
+	QString s = p->config->readEntry( QString::fromAscii( "useDcc" ), QString() );
+	kDebug( 14100 ) << "dccEnabled: " << s;
 	if ( s == QString::fromAscii( "enabled" ) ) {
 		return true;
 	}
@@ -1147,8 +1189,7 @@ GaduAccount::setDcc( bool d )
 	if ( p->session_->isConnected() && d ) {
 		dccOn();
 	}
-
-	kdDebug( 14100 ) << "s: "<<s<<endl;
+	kDebug( 14100 ) << "s: "<<s;
 
 	return f;
 }
@@ -1156,7 +1197,7 @@ GaduAccount::setDcc( bool d )
 void
 GaduAccount::saveFriendsMode( bool i )
 {
-	p->config->writeEntry( QString::fromAscii( "forFriends" ), 
+	p->config->writeEntry( QString::fromAscii( "forFriends" ),
 			i == true ? QString::fromAscii( "1" ) : QString::fromAscii( "0" ) );
 }
 
@@ -1167,7 +1208,7 @@ GaduAccount::loadFriendsMode()
 	bool r;
 	int n;
 
-	s = p->config->readEntry( QString::fromAscii( "forFriends" ) );
+	s = p->config->readEntry( QString::fromAscii( "forFriends" ), QString() );
 	n = s.toInt( &r );
 
 	if ( n ) {
@@ -1185,23 +1226,23 @@ GaduAccount::ignoreAnons()
 	QString s;
 	bool r;
 	int n;
-	
-	s = p->config->readEntry( QString::fromAscii( "ignoreAnons" ) );
+
+	s = p->config->readEntry( QString( "ignoreAnons" ), QString() );
 	n = s.toInt( &r );
-	
+
 	if ( n ) {
 		return true;
 	}
 
 	return false;
-	
+
 }
 
-void 
+void
 GaduAccount::setIgnoreAnons( bool i )
 {
 	p->ignoreAnons = i;
-	p->config->writeEntry( QString::fromAscii( "ignoreAnons" ), 
+	p->config->writeEntry( QString::fromAscii( "ignoreAnons" ),
 			i == true ? QString::fromAscii( "1" ) : QString::fromAscii( "0" ) );
 }
 
@@ -1213,16 +1254,16 @@ GaduAccount::useTls()
 	unsigned int oldC;
 	tlsConnection Tls;
 
-	s = p->config->readEntry( QString::fromAscii( "useEncryptedConnection" ) );
+	s = p->config->readEntry( QString::fromAscii( "useEncryptedConnection" ), QString() );
 	oldC = s.toUInt( &c );
 	// we have old format
 	if ( c ) {
-		kdDebug( 14100 ) << "old format for param useEncryptedConnection, value " <<
-				oldC << " willl be converted to new string value" << endl;
+		kDebug( 14100 ) << "old format for param useEncryptedConnection, value " <<
+				oldC << " will be converted to new string value" << endl;
 		setUseTls( (tlsConnection) oldC );
 		// should be string now, unless there was an error reading
-		s = p->config->readEntry( QString::fromAscii( "useEncryptedConnection" ) );
-		kdDebug( 14100 ) << "new useEncryptedConnection value : " << s << endl;
+		s = p->config->readEntry( QString::fromAscii( "useEncryptedConnection" ), QString() );
+		kDebug( 14100 ) << "new useEncryptedConnection value : " << s;
 	}
 
 	Tls = TLS_no;
