@@ -2,7 +2,7 @@
 /*
  *            kPPP: A front end for pppd for the KDE project
  *
- * $Id: scriptedit.h 212185 2003-03-07 22:11:39Z waba $
+ * $Id: scriptedit.h 535556 2006-04-29 19:10:24Z coolo $
  *
  *             Copyright (C) 1997 Bernd Johannes Wuebben
  *                    wuebben@math.cornell.edu
@@ -22,7 +22,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #ifndef _SCRIPTEDIT_H_
@@ -36,7 +36,7 @@ class QLineEdit;
 class ScriptEdit : public QWidget {
 Q_OBJECT
 public:
-  ScriptEdit( QWidget *parent=0, const char *name=0 );
+  ScriptEdit( QWidget *parent=0 );
   ~ScriptEdit() {}
 
   QString text()const;
